@@ -106,6 +106,29 @@ def basemodel_to_str(
     )
 
 
+def resolver_equal_or_better(
+    resolver_a: "ResolverType", resolver_b: "ResolverType"
+) -> bool:
+    if resolver_a.to_str() == resolver_b.to_str():
+        return True
+    if resolver_a.to_str(ignore_nested=True) != resolver_b.to_str(ignore_nested=True):
+        return False
+    # now go to nesteds
+    for (
+        nested_resolver_name_b,
+        nested_resolver_b,
+    ) in resolver_b._nested_resolvers.items():
+        nested_resolver_a = resolver_a._nested_resolvers.get(nested_resolver_name_b)
+        if not nested_resolver_a:
+            print(
+                f"{nested_resolver_name_b} is not in the cached {resolver_a._model_name} resolver"
+            )
+            return False
+        if not resolver_equal_or_better(nested_resolver_a, nested_resolver_b):
+            return False
+    return True
+
+
 class Node(BaseModel, T.Generic[InsertType]):
     id: UUID = Field(..., allow_mutation=False)
 
@@ -189,7 +212,7 @@ class Node(BaseModel, T.Generic[InsertType]):
         if edge_cache := self.cache.get(edge_name):
             if force_use_stale:
                 return edge_cache.val
-            if edge_cache.resolver.to_str() != edge_resolver.to_str():
+            if not resolver_equal_or_better(edge_cache.resolver, edge_resolver):
                 if print_forced_refresh:
                     print(
                         f"resolvers are different so removing {edge_name} from the cache, old: {edge_cache.resolver.to_str()}, new: {edge_resolver.to_str()}"
