@@ -254,7 +254,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             s += f" {self._limit_str}"
         return s
 
-    def to_str(self, include_filters: bool = True) -> str:
+    def to_str(self, include_filters: bool = True, ignore_nested: bool = False) -> str:
         """
         OUTPUT: { name, created_at, bookings: { created_at } FILTER .created_at > $booking_created_at } FILTER .name = $name }
         """
@@ -263,9 +263,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         if self._extra_fields:
             s += f", {self._extra_fields}"
         resolver_strs: T.List[str] = []
-        for field_name, resolver in self._nested_resolvers.items():
-            resolver_substring = f"{field_name}: {resolver.to_str()}"
-            resolver_strs.append(resolver_substring)
+        if not ignore_nested:
+            for field_name, resolver in self._nested_resolvers.items():
+                resolver_substring = f"{field_name}: {resolver.to_str()}"
+                resolver_strs.append(resolver_substring)
         nested_resolver_str = ", ".join(resolver_strs)
         if nested_resolver_str:
             s += f", {nested_resolver_str}"
